@@ -3,12 +3,12 @@
 
 """Defines the ErrorAnalysis dashboard class."""
 
-from .error_analysis_dashboard_input import ErrorAnalysisDashboardInput
-from .dashboard import Dashboard
-from .constants import ModelTask
-
 from flask import jsonify, request
 
+from .constants import ModelTask
+from .dashboard import Dashboard
+from .error_analysis_dashboard_input import ErrorAnalysisDashboardInput
+
 DEFAULT_MAX_DEPTH = 3
 DEFAULT_NUM_LEAVES = 31
 DEFAULT_MIN_CHILD_SAMPLES = 20
@@ -68,10 +68,11 @@ class ErrorAnalysisDashboard(Dashboard):
         'macro_recall_score' for multiclass classification,
         'precision_score' for binary classification and
         'micro_precision_score' or 'macro_precision_score'
-        for multiclass classification, 'f1_score',
-        and 'accuracy_score'. Supported regression
-        metrics include 'mean_absolute_error', 'mean_squared_error',
-        'r2_score', and 'median_absolute_error'.
+        for multiclass classification, 'f1_score' for binary
+        classification and 'micro_f1_score' or 'macro_f1_score'
+        for multiclass classification, and 'accuracy_score'.
+        Supported regression metrics include 'mean_absolute_error',
+        'mean_squared_error', 'r2_score', and 'median_absolute_error'.
     :type metric: str
     :param max_depth: The maximum depth of the surrogate tree trained
         on errors.
@@ -88,8 +89,7 @@ class ErrorAnalysisDashboard(Dashboard):
 
     :Example:
 
-    # Run simple view of error analysis with just predictions and
-    # true labels
+    Run simple view of error analysis with just predictions and true labels
 
     >>> predictions = model.predict(X_test)
     >>> from raiwidgets import ErrorAnalysisDashboard
@@ -98,7 +98,7 @@ class ErrorAnalysisDashboard(Dashboard):
 
     :Example:
 
-    # Run error analysis with a model and a computed explanation
+    Run error analysis with a model and a computed explanation
 
     >>> from raiwidgets import ErrorAnalysisDashboard
     >>> ErrorAnalysisDashboard(global_explanation, model,
@@ -106,8 +106,7 @@ class ErrorAnalysisDashboard(Dashboard):
 
     :Example:
 
-    # Run error analysis on large data and a downsampled dataset
-    # for the UI
+    Run error analysis on large data and a downsampled dataset for the UI
 
     >>> from raiwidgets import ErrorAnalysisDashboard
     >>> ErrorAnalysisDashboard(sample_dataset=X_test_sample,
